/**
 * @file
 * Vue app for cart.
 */

(function ($) {
  "use strict";
  console.log('custom/syncart/cart.js');

  Vue.component('product', {
    props: {},
    methods: {},
    created() {}
  });

  Vue.component('cart-field', {
    props: {
      pid: 0,
    },
    data() {
      return {
        inCart: false,
        productsLoaded: false,
      }
    },
    methods: {
      initProduct() {
        this.productsLoaded = true;
      },
      addToCart(variation_id) {
        axios.get('/cart/add-item', {params: {'vid': variation_id}}).then(
          response => {
            this.inCart = true;
            this.$root.$emit('update_cart', response.data);
            console.log([this.pid, variation_id]);
          },
          response => {
            console.log(response);
          }
        )
      }
    },
    created() {
      this.initProduct();
    }
  });

  Vue.component('cart', {
      data() {
        return {
          cart: {
            items: {},
            quantity: 0,
            total: 0,
          },
          ready: false,
        }
      },
      methods: {
        initCart() {
          axios.get('/api/cart-load').then(
            response => {
              this.cart = response.data;
              if (this.cart.quantity > 0 ) {
                this.ready = true;
              }
              this.$root.$emit('update_cart', this.cart);
            },
            response => {
              console.log(response);
            }
          )
        },
        changeQuantity(vid, quantity) {
          quantity = !quantity || quantity < 1 ? 1 : quantity;
          let stock = this.cart.items[vid].stock;
          if (quantity <= stock || stock == 0) {
            axios.get('/cart/set-product-quantity/' + vid, {
              params: {
                quantity: quantity,
              },
            }).then(
              response => {
                this.cart = response.data;
                console.log(this.cart);
                this.initCart();
              },
              response => {
                console.log(response);
              }
            );
          }
        },
        removeItem(vid) {
          axios.get('/cart/remove-cart-item/' + vid).then(
            response => {
              this.ready = false;
              this.initCart();
            },
            response => {
              console.log(response);
            }
          );
        },
        numberFormat(number, decimals = 2, dec_point = '.', thousands_sep = ' ') {
          let s_number = Math.abs(
            parseInt(number = (+number || 0).toFixed(decimals))
          ) + "";
          let len = s_number.length;
          let tchunk = len > 3 ? len % 3 : 0;
          let ch_first = (tchunk ? s_number.substr(0, tchunk) + thousands_sep : '');
          let ch_rest = s_number.substr(tchunk).replace(/(\d\d\d)(?=\d)/g, '$1' + thousands_sep);
          let ch_last = decimals ? dec_point + (Math.abs(number) - s_number).toFixed(decimals).slice(2) : '';
          return ch_first + ch_rest + ch_last;
        },
        isEmpty(value) {
          if (!!value && value instanceof Array) {
            return value.length < 1
          }
          if (!!value && typeof value === 'object') {
            for (var key in value) {
              if (hasOwnProperty.call(value, key)) {
                return false
              }
            }
          }
          return !value
        }
      },
      created() {
        this.initCart();
      }
  });

})(this.jQuery);
