<?php

namespace Drupal\syncart\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Serialization\Json;

/**
 * Class FavoriteController.
 */
class FavoriteController extends ControllerBase {
  /**
   * Constructs a new FavoriteController object.
   */
  public function __construct() {
    $this->entityTypeManager = \Drupal::entityTypeManager();
    $this->renderer = \Drupal::service('renderer');
    $this->productStorage = $this->entityTypeManager->getStorage('commerce_product');
    $this->viewBuilder = $this->entityTypeManager->getViewBuilder('commerce_product');
    $this->outlet = FALSE;
  }

  /**
   * Make products teaser.
   */
  public function makeProductsTeaser($products) {
    $output = [];
    foreach ($products as $product) {
      $view_builder = \Drupal::entityTypeManager()->getViewBuilder('commerce_product');
      $storage = \Drupal::entityTypeManager()->getStorage('commerce_product');
      $build = $view_builder->view($product, 'teaser');
      $output[] = render($build);
    }
    return $output;
  }

  /**
   * Favorites page.
   */
  public function favoritesPage() {
    $output = $this->getFavoritesProducts();
    return [
      '#theme' => 'syncart-favorites',
      '#data' => $output,
    ];
  }

  /**
   * Get favorites products.
   */
  public function getFavoritesProducts() {
    $output = [];
    $favorites = $this->getFavoritesIds();
    if ($favorites) {
      $products = $this->productStorage->loadMultiple($favorites);
      $output = $this->makeProductsTeaser($products);
    }
    return $output;
  }

  /**
   * Get product ids.
   */
  public function getFavoritesIds() {
    $uid = \Drupal::currentUser()->id();
    $favorites = [];

    if (isset($_COOKIE['favorites'])) {
      $cookieFavorites = $_COOKIE['favorites'];
      $favorites = Json::decode($cookieFavorites);
    }

    if (is_array($favorites)) {
      $favorites = array_keys($favorites);
    }

    return $favorites;
  }

}
